package cordova.plugin.documentreader;

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import com.regula.documentreader.api.DocumentReader;
import com.regula.documentreader.api.ParamsCustomization;
import com.regula.documentreader.api.params.Functionality;
import com.regula.documentreader.api.params.ProcessParam;
import com.regula.documentreader.api.params.DataGroups;
import android.widget.ImageView.ScaleType;
import android.graphics.Typeface;
import android.graphics.Matrix;
import android.util.Log;

public class RegulaConfig {

  static String[] extractStringArray(JSONArray readableArray) throws JSONException {
    String[] result = new String[readableArray.length()];
    for (int i = 0; i < readableArray.length(); i++) {
      result[i] = readableArray.getString(i);
    }
    return result;
  }

  static int[] extractIntArray(JSONArray readableArray) throws JSONException {
    int[] result = new int[readableArray.length()];
    for (int i = 0; i < readableArray.length(); i++) {
      result[i] = readableArray.getInt(i);
    }
    return result;
  }

  static float[] extractFloatArray(JSONArray readableArray) throws JSONException {
    float[] result = new float[readableArray.length()];
    for (int i = 0; i < readableArray.length(); i++) {
      result[i] = (float) readableArray.getDouble(i);
    }
    return result;
  }

  public static void setConfig(DocumentReader reader, JSONObject opts) {
    try {
      if (opts.has("customization")) {
        setCustomization(reader.customization(), opts.getJSONObject("customization"));
      }
      if (opts.has("functionality")) {
        setFunctionality(reader.functionality(), opts.getJSONObject("functionality"));
      }
      if (opts.has("processParams")) {
        reader.processParams().fromJson(opts.getJSONObject("processParams").toString());
      }
    } catch (JSONException e) {
      e.printStackTrace();
    }
  }

  public static JSONObject getConfig(DocumentReader reader) {
    JSONObject object = new JSONObject();
    try {
      object.put("customization", getCustomization(reader.customization()));
      object.put("functionality", getFunctionality(reader.functionality()));
      object.put("processParams", getProcessParams(reader.processParams()));
    } catch (JSONException e) {
    }

    return object;
  }

  public static void setFunctionality(Functionality functionality, JSONObject opts) throws JSONException {
    if (opts.has("mPictureOnBoundsReady")) {
      functionality.setPictureOnBoundsReady(opts.getBoolean("mPictureOnBoundsReady"));
    }
    if (opts.has("mShowTorchButton")) {
      functionality.setShowTorchButton(opts.getBoolean("mShowTorchButton"));
    }
    if (opts.has("mShowCloseButton")) {
      functionality.setShowCloseButton(opts.getBoolean("mShowCloseButton"));
    }
    if (opts.has("mVideoCaptureMotionControl")) {
      functionality.setVideoCaptureMotionControl(opts.getBoolean("mVideoCaptureMotionControl"));
    }
    if (opts.has("mShowCaptureButton")) {
      functionality.setShowCaptureButton(opts.getBoolean("mShowCaptureButton"));
    }
    if (opts.has("mShowChangeFrameButton")) {
      functionality.setShowChangeFrameButton(opts.getBoolean("mShowChangeFrameButton"));
    }
    if (opts.has("mShowCaptureButtonDelayFromDetect")) {
      functionality.setShowCaptureButtonDelayFromDetect(opts.getInt("mShowCaptureButtonDelayFromDetect"));
    }
    if (opts.has("mShowCaptureButtonDelayFromStart")) {
      functionality.setShowCaptureButtonDelayFromStart(opts.getInt("mShowCaptureButtonDelayFromStart"));
    }
    if (opts.has("mIsOnlineMode")) {
      functionality.setOnlineMode(opts.getBoolean("mIsOnlineMode"));
    }
    if (opts.has("mDatabaseAutoupdate")) {
      functionality.setDatabaseAutoupdate(opts.getBoolean("mDatabaseAutoupdate"));
    }
    if (opts.has("mShowSkipNextPageButton")) {
      functionality.setShowSkipNextPageButton(opts.getBoolean("mShowSkipNextPageButton"));
    }
    if (opts.has("mUseAuthenticator")) {
      functionality.setUseAuthenticator(opts.getBoolean("mUseAuthenticator"));
    }
    if (opts.has("mSkipFocusingFrames")) {
      functionality.setSkipFocusingFrames(opts.getBoolean("mSkipFocusingFrames"));
    }
    if (opts.has("mShowCameraSwitchBtn")) {
      functionality.setShowCameraSwitchBtn(opts.getBoolean("mShowCameraSwitchBtn"));
    }
    if (opts.has("mCameraFrame")) {
      functionality.setCameraFrame(opts.getString("mCameraFrame"));
    }
    if (opts.has("mServiceURL")) {
      functionality.setServiceURL(opts.getString("mServiceURL"));
    }
    if (opts.has("mDatabaseIdentifier")) {
      functionality.setDatabaseIdentifier(opts.getString("mDatabaseIdentifier"));
    }
    if (opts.has("mBtDeviceName")) {
      functionality.setBtDeviceName(opts.getString("mBtDeviceName"));
    }
    if (opts.has("mOrientation")) {
      functionality.setOrientation(opts.getInt("mOrientation"));
    }
  }

  public static void setCustomization(ParamsCustomization customization, JSONObject opts) throws JSONException {
    if (opts.has("mStatus")) {
      customization.setStatus(opts.getString("mStatus"));
    }
    if (opts.has("mResultStatus")) {
      customization.setResultStatus(opts.getString("mResultStatus"));
    }
    if (opts.has("mCameraFrameDefaultColor")) {
      customization.setCameraFrameDefaultColor(opts.getString("mCameraFrameDefaultColor"));
    }
    if (opts.has("mCameraFrameActiveColor")) {
      customization.setCameraFrameActiveColor(opts.getString("mCameraFrameActiveColor"));
    }
    if (opts.has("mStatusTextColor")) {
      customization.setStatusTextColor(opts.getString("mStatusTextColor"));
    }
    if (opts.has("mResultStatusTextColor")) {
      customization.setResultStatusTextColor(opts.getString("mResultStatusTextColor"));
    }
    if (opts.has("mResultStatusBackgroundColor")) {
      customization.setResultStatusBackgroundColor(opts.getString("mResultStatusBackgroundColor"));
    }
    if (opts.has("mMultipageButtonBackgroundColor")) {
      customization.setMultipageButtonBackgroundColor(opts.getString("mMultipageButtonBackgroundColor"));
    }
    if (opts.has("mTintColor")) {
      customization.setTintColor(opts.getString("mTintColor"));
    }
    if (opts.has("mActivityIndicatorColor")) {
      customization.setActivityIndicatorColor(opts.getString("mActivityIndicatorColor"));
    }
    if (opts.has("mShowStatusMessages")) {
      customization.setShowStatusMessages(opts.getBoolean("mShowStatusMessages"));
    }
    if (opts.has("mShowResultStatusMessages")) {
      customization.setShowResultStatusMessages(opts.getBoolean("mShowResultStatusMessages"));
    }
    if (opts.has("mShowHelpAnimation")) {
      customization.setShowHelpAnimation(opts.getBoolean("mShowHelpAnimation"));
    }
    if (opts.has("mShowNextPageAnimation")) {
      customization.setShowNextPageAnimation(opts.getBoolean("mShowNextPageAnimation"));
    }
    if (opts.has("mShowBackgroundMask")) {
      customization.setShowBackgroundMask(opts.getBoolean("mShowBackgroundMask"));
    }
    if (opts.has("mCameraFrameBorderWidth")) {
      customization.setCameraFrameBorderWidth(opts.getInt("mCameraFrameBorderWidth"));
    }
    if (opts.has("mStatusTextSize")) {
      customization.setStatusTextSize(opts.getInt("mStatusTextSize"));
    }
    if (opts.has("mCameraFrameLineLength")) {
      customization.setCameraFrameLineLength(opts.getInt("mCameraFrameLineLength"));
    }
    if (opts.has("mCameraFrameShapeType")) {
      customization.setCameraFrameShapeType(opts.getInt("mCameraFrameShapeType"));
    }
    if (opts.has("mResultStatusTextSize")) {
      customization.setResultStatusTextSize(opts.getInt("mResultStatusTextSize"));
    }
    if (opts.has("mHelpAnimationImageID")) {
      customization.setHelpAnimationImageID(opts.getInt("mHelpAnimationImageID"));
    }
    if (opts.has("mMultipageAnimationFrontImage")) {
      customization.setMultipageAnimationFrontImage(opts.getInt("mMultipageAnimationFrontImage"));
    }
    if (opts.has("mMultipageAnimationBackImage")) {
      customization.setMultipageAnimationBackImage(opts.getInt("mMultipageAnimationBackImage"));
    }
    if (opts.has("mBorderBackgroundImage")) {
      customization.setBorderBackgroundImage(opts.getInt("mBorderBackgroundImage"));
    }
    if (opts.has("mStatusPositionMultiplier")) {
      customization.setStatusPositionMultiplier(opts.getDouble("mStatusPositionMultiplier"));
    }
    if (opts.has("mResultStatusPositionMultiplier")) {
      customization.setResultStatusPositionMultiplier(opts.getDouble("mResultStatusPositionMultiplier"));
    }
    if (opts.has("mBackgroundMaskAlpha")) {
      customization.setBackgroundMaskAlpha((float) opts.getDouble("mBackgroundMaskAlpha"));
    }
    if (opts.has("mStatusTextFont")) {
      customization
          .setStatusTextFont(Typeface.create(opts.getString("mStatusTextFont"), opts.getInt("mStatusTextFontStyle")));
    }
    if (opts.has("mResultStatusTextFont")) {
      customization.setResultStatusTextFont(
          Typeface.create(opts.getString("mResultStatusTextFont"), opts.getInt("mResultStatusTextFontStyle")));
    }
    if (opts.has("mHelpAnimationImageScaleType")) {
      customization.setHelpAnimationImageScaleType(ScaleType.valueOf(opts.getString("mHelpAnimationImageScaleType")));
    }
    if (opts.has("mMultipageAnimationFrontImageScaleType")) {
      customization.setMultipageAnimationFrontImageScaleType(
          ScaleType.valueOf(opts.getString("mMultipageAnimationFrontImageScaleType")));
    }
    if (opts.has("mMultipageAnimationBackImageScaleType")) {
      customization.setMultipageAnimationBackImageScaleType(
          ScaleType.valueOf(opts.getString("mMultipageAnimationBackImageScaleType")));
    }
    if (opts.has("mHelpAnimationImageMatrix")) {
      Matrix matrix = new Matrix();
      matrix.setValues(extractFloatArray(opts.getJSONArray("mHelpAnimationImageMatrix")));
      customization.setHelpAnimationImageMatrix(matrix);
    }
    if (opts.has("mMultipageAnimationFrontImageMatrix")) {
      Matrix matrix = new Matrix();
      matrix.setValues(extractFloatArray(opts.getJSONArray("mMultipageAnimationFrontImageMatrix")));
      customization.setMultipageAnimationFrontImageMatrix(matrix);
    }
    if (opts.has("mMultipageAnimationBackImageMatrix")) {
      Matrix matrix = new Matrix();
      matrix.setValues(extractFloatArray(opts.getJSONArray("mMultipageAnimationBackImageMatrix")));
      customization.setMultipageAnimationBackImageMatrix(matrix);
    }
  }

  public static JSONObject getFunctionality(Functionality functionality) {
    JSONObject object = new JSONObject();
    try {
      object.put("mPictureOnBoundsReady", functionality.isPictureOnBoundsReady());
      object.put("mShowTorchButton", functionality.isShowTorchButton());
      object.put("mShowCloseButton", functionality.isShowCloseButton());
      object.put("mVideoCaptureMotionControl", functionality.isVideoCaptureMotionControl());
      object.put("mShowCaptureButton", functionality.isShowCaptureButton());
      object.put("mShowChangeFrameButton", functionality.isShowChangeFrameButton());
      object.put("mShowCaptureButtonDelayFromDetect", functionality.getShowCaptureButtonDelayFromDetect());
      object.put("mShowCaptureButtonDelayFromStart", functionality.getShowCaptureButtonDelayFromStart());
      object.put("mIsOnlineMode", functionality.isOnlineMode());
      object.put("mDatabaseAutoupdate", functionality.isDatabaseAutoupdate());
      object.put("mShowSkipNextPageButton", functionality.isShowSkipNextPageButton());
      object.put("mUseAuthenticator", functionality.isUseAuthenticator());
      object.put("mSkipFocusingFrames", functionality.isSkipFocusingFrames());
      object.put("mShowCameraSwitchBtn", functionality.isShowCameraSwitchBtn());
      object.put("mCameraFrame", functionality.getCameraFrame());
      object.put("mServiceURL", functionality.getServiceURL());
      object.put("mDatabaseIdentifier", functionality.getDatabaseIdentifier());
      object.put("mBtDeviceName", functionality.getBtDeviceName());
      object.put("mOrientation", functionality.getOrientation());
    } catch (JSONException e) {
    }

    return object;
  }

  public static JSONObject getCustomization(ParamsCustomization customization) {
    JSONObject object = new JSONObject();
    try {
      object.put("mStatus", customization.getStatus());
      object.put("mResultStatus", customization.getResultStatus());
      object.put("mCameraFrameDefaultColor", customization.getCameraFrameDefaultColor());
      object.put("mCameraFrameActiveColor", customization.getCameraFrameActiveColor());
      object.put("mStatusTextColor", customization.getStatusTextColor());
      object.put("mResultStatusTextColor", customization.getResultStatusTextColor());
      object.put("mResultStatusBackgroundColor", customization.getResultStatusBackgroundColor());
      object.put("mMultipageButtonBackgroundColor", customization.getMultipageButtonBackgroundColor());
      object.put("mTintColor", customization.getTintColor());
      object.put("mActivityIndicatorColor", customization.getActivityIndicatorColor());
      object.put("mShowStatusMessages", customization.isShowStatusMessages());
      object.put("mShowResultStatusMessages", customization.isShowResultStatusMessages());
      object.put("mShowHelpAnimation", customization.isShowHelpAnimation());
      object.put("mShowNextPageAnimation", customization.isShowNextPageAnimation());
      object.put("mShowBackgroundMask", customization.isShowBackgroundMask());
      object.put("mCameraFrameBorderWidth", customization.getCameraFrameBorderWidth());
      object.put("mStatusTextSize", customization.getStatusTextSize());
      object.put("mCameraFrameLineLength", customization.getCameraFrameLineLength());
      object.put("mCameraFrameShapeType", customization.getCameraFrameShapeType());
      object.put("mResultStatusTextSize", customization.getResultStatusTextSize());
      object.put("mHelpAnimationImageID", customization.getHelpAnimationImageID());
      object.put("mMultipageAnimationFrontImage", customization.getMultipageAnimationFrontImage());
      object.put("mMultipageAnimationBackImage", customization.getMultipageAnimationBackImage());
      object.put("mBorderBackgroundImage", customization.getBorderBackgroundImage());
      object.put("mHelpAnimationImageScaleType", customization.getHelpAnimationImageScaleType());
      object.put("mMultipageAnimationFrontImageScaleType", customization.getMultipageAnimationFrontImageScaleType());
      object.put("mMultipageAnimationBackImageScaleType", customization.getMultipageAnimationBackImageScaleType());
      object.put("mHelpAnimationImageMatrix", customization.getHelpAnimationImageMatrix());
      object.put("mMultipageAnimationFrontImageMatrix", customization.getMultipageAnimationFrontImageMatrix());
      object.put("mMultipageAnimationBackImageMatrix", customization.getMultipageAnimationBackImageMatrix());
      object.put("mStatusTextFont", customization.getStatusTextFont());
      object.put("mResultStatusTextFont", customization.getResultStatusTextFont());
      object.put("mStatusPositionMultiplier", customization.getStatusPositionMultiplier());
      object.put("mResultStatusPositionMultiplier", customization.getResultStatusPositionMultiplier());
      object.put("mBackgroundMaskAlpha", customization.getBackgroundMaskAlpha());
    } catch (JSONException e) {
    }

    return object;
  }

  public static JSONObject getProcessParams(ProcessParam processParams) {
    JSONObject object = new JSONObject();
    try {
      object.put("scenario", processParams.scenario);
      object.put("measureSystem", processParams.measureSystem);
      object.put("uvTorchEnabled", processParams.uvTorchEnabled);
      object.put("logs", processParams.logs);
      object.put("debugSaveImages", true);
      object.put("debugSaveLogs", processParams.debugSaveLogs);
      object.put("multipageProcessing", processParams.multipageProcessing);
      object.put("dateFormat", processParams.dateFormat);
      object.put("debugSaveCroppedImages", processParams.debugSaveCroppedImages);
      object.put("sessionLogFolder", processParams.sessionLogFolder);
      object.put("disableFocusingCheck", processParams.disableFocusingCheck);
      object.put("captureButtonScenario", processParams.captureButtonScenario);
      object.put("returnUncroppedImage", processParams.returnUncroppedImage);
      if (processParams.customParams != null) {
        object.put("customParams", processParams.customParams.toString());
      } else {
        object.put("customParams", new JSONArray());
      }

      JSONArray jdocumentIDList = new JSONArray();
      if (processParams.documentIDList != null && processParams.documentIDList.length > 0) {
        int index = 0;
        for (int item : processParams.documentIDList) {
          jdocumentIDList.put(index, item);
          index++;
        }
      }
      object.put("documentIDList", jdocumentIDList);

      JSONArray jdoBarcodes = new JSONArray();
      if (processParams.doBarcodes != null && processParams.doBarcodes.length > 0) {
        int index = 0;
        for (String item : processParams.doBarcodes) {
          jdoBarcodes.put(index, item);
          index++;
        }
      }
      object.put("doBarcodes", jdoBarcodes);

      JSONArray jfieldTypesFilter = new JSONArray();
      if (processParams.fieldTypesFilter != null && processParams.fieldTypesFilter.length > 0) {
        int index = 0;
        for (int item : processParams.fieldTypesFilter) {
          jfieldTypesFilter.put(index, item);
          index++;
        }
      }
      object.put("fieldTypesFilter", jfieldTypesFilter);
    } catch (Exception e) {
    }

    return object;
  }

  public static void setRfidScenario(DocumentReader reader, JSONObject opts) {
    try {
      if (opts.has("mPaceStaticBinding"))
        reader.Instance().rfidScenario().setPaceStaticBinding(opts.getBoolean("PACE_StaticBinding"));
      if (opts.has("mSignManagementAction"))
        reader.Instance().rfidScenario().setSignManagementAction(opts.getInt("mSignManagementAction"));
      if (opts.has("mReadingBuffer"))
        reader.Instance().rfidScenario().setReadingBuffer(opts.getInt("mReadingBuffer"));
      if (opts.has("mOnlineTAToSignDataType"))
        reader.Instance().rfidScenario().setOnlineTAToSignDataType(opts.getInt("mOnlineTAToSignDataType"));
      if (opts.has("mOnlineTA"))
        reader.Instance().rfidScenario().setOnlineTA(opts.getBoolean("mOnlineTA"));
      if (opts.has("mWriteEid"))
        reader.Instance().rfidScenario().setWriteEid(opts.getBoolean("mWriteEid"));
      if (opts.has("mProfilerType"))
        reader.Instance().rfidScenario().setProfilerType(opts.getInt("mProfilerType"));
      if (opts.has("mAuthProcType"))
        reader.Instance().rfidScenario().setAuthProcType(opts.getInt("mAuthProcType"));
      if (opts.has("mBaseSMProcedure"))
        reader.Instance().rfidScenario().setBaseSMProcedure(opts.getInt("mBaseSMProcedure"));
      if (opts.has("mPacePasswordType"))
        reader.Instance().rfidScenario().setPacePasswordType(opts.getInt("mPacePasswordType"));
      if (opts.has("mTerminalType"))
        reader.Instance().rfidScenario().setTerminalType(opts.getInt("mTerminalType"));
      if (opts.has("mUniversalAccessRights"))
        reader.Instance().rfidScenario().setUniversalAccessRights(opts.getBoolean("mUniversalAccessRights"));
      if (opts.has("mAuthorizedRestrictedIdentification"))
        reader.Instance().rfidScenario()
            .setAuthorizedRestrictedIdentification(opts.getBoolean("mAuthorizedRestrictedIdentification"));
      if (opts.has("mAuxVerificationCommunityID"))
        reader.Instance().rfidScenario().setAuxVerificationCommunityID(opts.getBoolean("mAuxVerificationCommunityID"));
      if (opts.has("mAuxVerificationDateOfBirth"))
        reader.Instance().rfidScenario().setAuxVerificationDateOfBirth(opts.getBoolean("mAuxVerificationDateOfBirth"));
      if (opts.has("mSkipAA"))
        reader.Instance().rfidScenario().setSkipAA(opts.getBoolean("mSkipAA"));
      if (opts.has("mStrictProcessing"))
        reader.Instance().rfidScenario().setStrictProcessing(opts.getBoolean("mStrictProcessing"));
      if (opts.has("mPkdDSCertPriority"))
        reader.Instance().rfidScenario().setPkdDSCertPriority(opts.getBoolean("mPkdDSCertPriority"));
      if (opts.has("mPkdUseExternalCSCA"))
        reader.Instance().rfidScenario().setPkdUseExternalCSCA(opts.getBoolean("mPkdUseExternalCSCA"));
      if (opts.has("mTrustedPKD"))
        reader.Instance().rfidScenario().setTrustedPKD(opts.getBoolean("mTrustedPKD"));
      if (opts.has("mPassiveAuth"))
        reader.Instance().rfidScenario().setPassiveAuth(opts.getBoolean("mPassiveAuth"));
      if (opts.has("mPassword"))
        reader.Instance().rfidScenario().setPassword(opts.getString("mPassword"));
      if (opts.has("mUseSFI"))
        reader.Instance().rfidScenario().setUseSFI(opts.getBoolean("mUseSFI"));
      if (opts.has("mPkdPA"))
        reader.Instance().rfidScenario().setPkdPA(opts.getString("mPkdPA"));
      if (opts.has("mPkdEAC"))
        reader.Instance().rfidScenario().setPkdEAC(opts.getString("mPkdEAC"));
      if (opts.has("mReadEPassport"))
        reader.Instance().rfidScenario().setReadEPassport(opts.getBoolean("mReadEPassport"));
      if (opts.has("mReadEID"))
        reader.Instance().rfidScenario().setReadEID(opts.getBoolean("mReadEID"));
      if (opts.has("mReadEDL"))
        reader.Instance().rfidScenario().setReadEDL(opts.getBoolean("mReadEDL"));
      if (opts.has("mMrz"))
        reader.Instance().rfidScenario().setMrz(opts.getString("mMrz"));
      if (opts.has("mESignPINDefault"))
        reader.Instance().rfidScenario().seteSignPINDefault(opts.getString("mESignPINDefault"));
      if (opts.has("mESignPINNewValue"))
        reader.Instance().rfidScenario().seteSignPINNewValue(opts.getString("mESignPINNewValue"));
      if (opts.has("mAuthorizedSTSignature"))
        reader.Instance().rfidScenario().setAuthorizedSTSignature(opts.getBoolean("mAuthorizedSTSignature"));
      if (opts.has("mAuthorizedSTQSignature"))
        reader.Instance().rfidScenario().setAuthorizedSTQSignature(opts.getBoolean("mAuthorizedSTQSignature"));
      if (opts.has("mAuthorizedWriteDG17"))
        reader.Instance().rfidScenario().setAuthorizedWriteDG17(opts.getBoolean("mAuthorizedWriteDG17"));
      if (opts.has("mAuthorizedWriteDG18"))
        reader.Instance().rfidScenario().setAuthorizedWriteDG18(opts.getBoolean("mAuthorizedWriteDG18"));
      if (opts.has("mAuthorizedWriteDG19"))
        reader.Instance().rfidScenario().setAuthorizedWriteDG19(opts.getBoolean("mAuthorizedWriteDG19"));
      if (opts.has("mAuthorizedWriteDG20"))
        reader.Instance().rfidScenario().setAuthorizedWriteDG20(opts.getBoolean("mAuthorizedWriteDG20"));
      if (opts.has("mAuthorizedWriteDG21"))
        reader.Instance().rfidScenario().setAuthorizedWriteDG21(opts.getBoolean("mAuthorizedWriteDG21"));
      if (opts.has("mAuthorizedVerifyAge"))
        reader.Instance().rfidScenario().setAuthorizedVerifyAge(opts.getBoolean("mAuthorizedVerifyAge"));
      if (opts.has("mAuthorizedVerifyCommunityID"))
        reader.Instance().rfidScenario()
            .setAuthorizedVerifyCommunityID(opts.getBoolean("mAuthorizedVerifyCommunityID"));
      if (opts.has("mAuthorizedPrivilegedTerminal"))
        reader.Instance().rfidScenario()
            .setAuthorizedPrivilegedTerminal(opts.getBoolean("mAuthorizedPrivilegedTerminal"));
      if (opts.has("mAuthorizedCANAllowed"))
        reader.Instance().rfidScenario().setAuthorizedCANAllowed(opts.getBoolean("mAuthorizedCANAllowed"));
      if (opts.has("mAuthorizedPINManagement"))
        reader.Instance().rfidScenario().setAuthorizedPINManagment(opts.getBoolean("mAuthorizedPINManagement"));
      if (opts.has("mAuthorizedInstallCert"))
        reader.Instance().rfidScenario().setAuthorizedInstallCert(opts.getBoolean("mAuthorizedInstallCert"));
      if (opts.has("mAuthorizedInstallQCert"))
        reader.Instance().rfidScenario().setAuthorizedInstallQCert(opts.getBoolean("mAuthorizedInstallQCert"));
      if (opts.has("ePassportDataGroups"))
        setDataGroups(reader.Instance().rfidScenario().ePassportDataGroups(),
            opts.getJSONObject("ePassportDataGroups"));
      if (opts.has("eIDDataGroups"))
        setDataGroups(reader.Instance().rfidScenario().eIDDataGroups(), opts.getJSONObject("eIDDataGroups"));
      if (opts.has("eDLDataGroups"))
        setDataGroups(reader.Instance().rfidScenario().eDLDataGroups(), opts.getJSONObject("eDLDataGroups"));
    } catch (JSONException e) {
      e.printStackTrace();
    }
  }

  private static void setDataGroups(DataGroups dataGroup, JSONObject opts) throws JSONException {
    if (opts.has("DG1"))
      dataGroup.setDG1(opts.getBoolean("DG1"));
    if (opts.has("DG2"))
      dataGroup.setDG2(opts.getBoolean("DG2"));
    if (opts.has("DG3"))
      dataGroup.setDG3(opts.getBoolean("DG3"));
    if (opts.has("DG4"))
      dataGroup.setDG4(opts.getBoolean("DG4"));
    if (opts.has("DG5"))
      dataGroup.setDG5(opts.getBoolean("DG5"));
    if (opts.has("DG6"))
      dataGroup.setDG6(opts.getBoolean("DG6"));
    if (opts.has("DG7"))
      dataGroup.setDG7(opts.getBoolean("DG7"));
    if (opts.has("DG8"))
      dataGroup.setDG8(opts.getBoolean("DG8"));
    if (opts.has("DG9"))
      dataGroup.setDG9(opts.getBoolean("DG9"));
    if (opts.has("DG10"))
      dataGroup.setDG10(opts.getBoolean("DG10"));
    if (opts.has("DG11"))
      dataGroup.setDG11(opts.getBoolean("DG11"));
    if (opts.has("DG12"))
      dataGroup.setDG12(opts.getBoolean("DG12"));
    if (opts.has("DG13"))
      dataGroup.setDG13(opts.getBoolean("DG13"));
    if (opts.has("DG14"))
      dataGroup.setDG14(opts.getBoolean("DG14"));
    if (opts.has("DG15"))
      dataGroup.setDG15(opts.getBoolean("DG15"));
    if (opts.has("DG16"))
      dataGroup.setDG16(opts.getBoolean("DG16"));
  }
}